==> teamapps-core-system-model-0.1-sources.jar: org/teamapps/model/controlcenter/UdbUserRoleAssignment.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.*;
import org.teamapps.universaldb.index.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.pojo.template.*;
import org.teamapps.universaldb.record.*;
import org.teamapps.universaldb.context.*;

import java.util.*;
import java.time.*;
import java.io.*;
import java.util.concurrent.*;
import java.util.function.Supplier;


public class UdbUserRoleAssignment extends AbstractUdbEntity<UserRoleAssignment> implements UserRoleAssignment {
	protected static TableIndex table;
	protected static IntegerIndex metaCreationDate;
	protected static IntegerIndex metaCreatedBy;
	protected static IntegerIndex metaModificationDate;
	protected static IntegerIndex metaModifiedBy;
	protected static IntegerIndex metaDeletionDate;
	protected static IntegerIndex metaDeletedBy;
	protected static IntegerIndex metaRestoreDate;
	protected static IntegerIndex metaRestoredBy;
	protected static SingleReferenceIndex user;
	protected static SingleReferenceIndex role;
	protected static SingleReferenceIndex organizationUnit;
	protected static IntegerIndex delegatedCustomPrivilegeObjectId;
	protected static BooleanIndex mainResponsible;
	protected static IntegerIndex lastVerified;
	protected static SingleReferenceIndex lastVerifiedBy;

    private static void setTableIndex(TableIndex tableIndex) {
        table = tableIndex;
		metaCreationDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_CREATION_DATE);
		metaCreatedBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_CREATED_BY);
		metaModificationDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_MODIFICATION_DATE);
		metaModifiedBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_MODIFIED_BY);
		metaDeletionDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_DELETION_DATE);
		metaDeletedBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_DELETED_BY);
		metaRestoreDate = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_RESTORE_DATE);
		metaRestoredBy = (IntegerIndex) tableIndex.getColumnIndex(FIELD_META_RESTORED_BY);
		user = (SingleReferenceIndex) tableIndex.getColumnIndex(FIELD_USER);
		role = (SingleReferenceIndex) tableIndex.getColumnIndex(FIELD_ROLE);
		organizationUnit = (SingleReferenceIndex) tableIndex.getColumnIndex(FIELD_ORGANIZATION_UNIT);
		delegatedCustomPrivilegeObjectId = (IntegerIndex) tableIndex.getColumnIndex(FIELD_DELEGATED_CUSTOM_PRIVILEGE_OBJECT_ID);
		mainResponsible = (BooleanIndex) tableIndex.getColumnIndex(FIELD_MAIN_RESPONSIBLE);
		lastVerified = (IntegerIndex) tableIndex.getColumnIndex(FIELD_LAST_VERIFIED);
		lastVerifiedBy = (SingleReferenceIndex) tableIndex.getColumnIndex(FIELD_LAST_VERIFIED_BY);
    }

    public static List<UserRoleAssignment> getAll() {
        return new EntityBitSetList<>(UserRoleAssignment.getBuilder(), table.getRecordBitSet());
    }

    public static List<UserRoleAssignment> getDeletedRecords() {
        return new EntityBitSetList<>(UserRoleAssignment.getBuilder(), table.getDeletedRecordsBitSet());
    }

    public static List<UserRoleAssignment> sort(List<UserRoleAssignment> list, String sortFieldName, boolean ascending, UserContext userContext, String ... path) {
    	return sort(table, list, sortFieldName, ascending, userContext, path);
    }

    public static List<UserRoleAssignment> sort(BitSet recordIds, String sortFieldName, boolean ascending, UserContext userContext, String ... path) {
        return sort(table, UserRoleAssignment.getBuilder(), recordIds, sortFieldName, ascending, userContext, path);
    }

    public static int getCount() {
        return table.getCount();
    }

    public UdbUserRoleAssignment() {
        super(table);
    }

    public UdbUserRoleAssignment(int id, boolean createEntity) {
        super(table, id, createEntity);
    }

    @Override
    public UserRoleAssignment build() {
        return new UdbUserRoleAssignment();
    }

    @Override
    public UserRoleAssignment build(int id) {
        return new UdbUserRoleAssignment(id, false);
    }

	@Override
	public Instant getMetaCreationDate() {
	    return getTimestampValue(metaCreationDate);
	}

	@Override
	public UserRoleAssignment setMetaCreationDate(Instant value) {
	    setTimestampValue(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaCreationDate);
	}

	@Override
	public UserRoleAssignment setMetaCreationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaCreationDate);
		return this;
	}

	@Override
	public long getMetaCreationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaCreationDate);
	}

	@Override
	public UserRoleAssignment setMetaCreationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreatedBy() {
        return getIntValue(metaCreatedBy);
	}

	@Override
	public UserRoleAssignment setMetaCreatedBy(int value) {
	    setIntValue(value, this.metaCreatedBy);
		return this;
	}

	@Override
	public Instant getMetaModificationDate() {
	    return getTimestampValue(metaModificationDate);
	}

	@Override
	public UserRoleAssignment setMetaModificationDate(Instant value) {
	    setTimestampValue(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModificationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaModificationDate);
	}

	@Override
	public UserRoleAssignment setMetaModificationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaModificationDate);
		return this;
	}

	@Override
	public long getMetaModificationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaModificationDate);
	}

	@Override
	public UserRoleAssignment setMetaModificationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModifiedBy() {
        return getIntValue(metaModifiedBy);
	}

	@Override
	public UserRoleAssignment setMetaModifiedBy(int value) {
	    setIntValue(value, this.metaModifiedBy);
		return this;
	}

	@Override
	public Instant getMetaDeletionDate() {
	    return getTimestampValue(metaDeletionDate);
	}

	@Override
	public UserRoleAssignment setMetaDeletionDate(Instant value) {
	    setTimestampValue(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletionDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaDeletionDate);
	}

	@Override
	public UserRoleAssignment setMetaDeletionDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public long getMetaDeletionDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaDeletionDate);
	}

	@Override
	public UserRoleAssignment setMetaDeletionDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletedBy() {
        return getIntValue(metaDeletedBy);
	}

	@Override
	public UserRoleAssignment setMetaDeletedBy(int value) {
	    setIntValue(value, this.metaDeletedBy);
		return this;
	}

	@Override
	public Instant getMetaRestoreDate() {
	    return getTimestampValue(metaRestoreDate);
	}

	@Override
	public UserRoleAssignment setMetaRestoreDate(Instant value) {
	    setTimestampValue(value, this.metaRestoreDate);
		return this;
	}

	@Override
	public int getMetaRestoreDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaRestoreDate);
	}

	@Override
	public UserRoleAssignment setMetaRestoreDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaRestoreDate);
		return this;
	}

	@Override
	public long getMetaRestoreDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaRestoreDate);
	}

	@Override
	public UserRoleAssignment setMetaRestoreDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaRestoreDate);
		return this;
	}

	@Override
	public int getMetaRestoredBy() {
        return getIntValue(metaRestoredBy);
	}

	@Override
	public UserRoleAssignment setMetaRestoredBy(int value) {
	    setIntValue(value, this.metaRestoredBy);
		return this;
	}

	@Override
	public User getUser() {
		if (isChanged(user)) {
			return (User) getReferenceChangeValue(user);
		} else {
			int id = user.getValue(getId());
			if (id > 0) {
				return User.getById(id);
			} else {
				return null;
			}
		}
	}

	@Override
	public UserRoleAssignment setUser(User value) {
		setSingleReferenceValue(user, value, table);
		return this;
	}

	@Override
	public Role getRole() {
		if (isChanged(role)) {
			return (Role) getReferenceChangeValue(role);
		} else {
			int id = role.getValue(getId());
			if (id > 0) {
				return Role.getById(id);
			} else {
				return null;
			}
		}
	}

	@Override
	public UserRoleAssignment setRole(Role value) {
		setSingleReferenceValue(role, value, table);
		return this;
	}

	@Override
	public OrganizationUnit getOrganizationUnit() {
		if (isChanged(organizationUnit)) {
			return (OrganizationUnit) getReferenceChangeValue(organizationUnit);
		} else {
			int id = organizationUnit.getValue(getId());
			if (id > 0) {
				return OrganizationUnit.getById(id);
			} else {
				return null;
			}
		}
	}

	@Override
	public UserRoleAssignment setOrganizationUnit(OrganizationUnit value) {
		setSingleReferenceValue(organizationUnit, value, table);
		return this;
	}

	@Override
	public int getDelegatedCustomPrivilegeObjectId() {
        return getIntValue(delegatedCustomPrivilegeObjectId);
	}

	@Override
	public UserRoleAssignment setDelegatedCustomPrivilegeObjectId(int value) {
	    setIntValue(value, this.delegatedCustomPrivilegeObjectId);
		return this;
	}

	@Override
	public boolean getMainResponsible() {
	    return getBooleanValue(mainResponsible);
	}

	@Override
	public UserRoleAssignment setMainResponsible(boolean value) {
	    setBooleanValue(value, this.mainResponsible);
		return this;
	}

	@Override
	public boolean isMainResponsible() {
	    return getBooleanValue(mainResponsible);
	}

	@Override
	public Instant getLastVerified() {
	    return getTimestampValue(lastVerified);
	}

	@Override
	public UserRoleAssignment setLastVerified(Instant value) {
	    setTimestampValue(value, this.lastVerified);
		return this;
	}

	@Override
	public int getLastVerifiedAsEpochSecond() {
	    return getTimestampAsEpochSecond(lastVerified);
	}

	@Override
	public UserRoleAssignment setLastVerifiedAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.lastVerified);
		return this;
	}

	@Override
	public long getLastVerifiedAsEpochMilli() {
	    return getTimestampAsEpochMilli(lastVerified);
	}

	@Override
	public UserRoleAssignment setLastVerifiedAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.lastVerified);
		return this;
	}

	@Override
	public User getLastVerifiedBy() {
		if (isChanged(lastVerifiedBy)) {
			return (User) getReferenceChangeValue(lastVerifiedBy);
		} else {
			int id = lastVerifiedBy.getValue(getId());
			if (id > 0) {
				return User.getById(id);
			} else {
				return null;
			}
		}
	}

	@Override
	public UserRoleAssignment setLastVerifiedBy(User value) {
		setSingleReferenceValue(lastVerifiedBy, value, table);
		return this;
	}



    @Override
    public UdbUserRoleAssignment save() {
        saveRecord();
        return this;
    }

    @Override
    public void delete() {
        deleteRecord();
    }

    @Override
    public void restoreDeleted() {
        restoreDeletedRecord();
    }
}

==> teamapps-core-system-model-0.9-sources.jar: org/teamapps/model/controlcenter/UdbUserRoleAssignment.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.*;
import org.teamapps.universaldb.index.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.pojo.template.*;
import org.teamapps.universaldb.record.*;
import org.teamapps.universaldb.context.*;

import java.util.*;
import java.time.*;
import java.io.*;
import java.util.concurrent.*;
import java.util.function.Supplier;


public class UdbUserRoleAssignment extends AbstractUdbEntity<UserRoleAssignment> implements UserRoleAssignment {
	protected static TableIndex table;
	protected static UniversalDB universalDB;
	protected static IntegerIndex metaCreationDate;
	protected static IntegerIndex metaCreatedBy;
	protected static IntegerIndex metaModificationDate;
	protected static IntegerIndex metaModifiedBy;
	protected static IntegerIndex metaDeletionDate;
	protected static IntegerIndex metaDeletedBy;
	protected static IntegerIndex metaRestoreDate;
	protected static IntegerIndex metaRestoredBy;
	protected static SingleReferenceIndex user;
	protected static SingleReferenceIndex role;
	protected static SingleReferenceIndex organizationUnit;
	protected static IntegerIndex delegatedCustomPrivilegeObjectId;
	protected static BooleanIndex mainResponsible;
	protected static IntegerIndex lastVerified;
	protected static SingleReferenceIndex lastVerifiedBy;

    private static void setTableIndex(TableIndex tableIndex, UniversalDB udb) {
		universalDB = udb;
        table = tableIndex;
		metaCreationDate = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_CREATION_DATE);
		metaCreatedBy = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_CREATED_BY);
		metaModificationDate = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_MODIFICATION_DATE);
		metaModifiedBy = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_MODIFIED_BY);
		metaDeletionDate = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_DELETION_DATE);
		metaDeletedBy = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_DELETED_BY);
		metaRestoreDate = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_RESTORE_DATE);
		metaRestoredBy = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_RESTORED_BY);
		user = (SingleReferenceIndex) tableIndex.getFieldIndex(FIELD_USER);
		role = (SingleReferenceIndex) tableIndex.getFieldIndex(FIELD_ROLE);
		organizationUnit = (SingleReferenceIndex) tableIndex.getFieldIndex(FIELD_ORGANIZATION_UNIT);
		delegatedCustomPrivilegeObjectId = (IntegerIndex) tableIndex.getFieldIndex(FIELD_DELEGATED_CUSTOM_PRIVILEGE_OBJECT_ID);
		mainResponsible = (BooleanIndex) tableIndex.getFieldIndex(FIELD_MAIN_RESPONSIBLE);
		lastVerified = (IntegerIndex) tableIndex.getFieldIndex(FIELD_LAST_VERIFIED);
		lastVerifiedBy = (SingleReferenceIndex) tableIndex.getFieldIndex(FIELD_LAST_VERIFIED_BY);
    }

    public static List<UserRoleAssignment> getAll() {
        return new EntityBitSetList<>(UserRoleAssignment.getBuilder(), table.getRecordBitSet());
    }

    public static List<UserRoleAssignment> getDeletedRecords() {
        return new EntityBitSetList<>(UserRoleAssignment.getBuilder(), table.getDeletedRecordsBitSet());
    }

    public static List<UserRoleAssignment> sort(List<UserRoleAssignment> list, String sortFieldName, boolean ascending, UserContext userContext, String ... path) {
    	return sort(table, list, sortFieldName, ascending, userContext, path);
    }

    public static List<UserRoleAssignment> sort(BitSet recordIds, String sortFieldName, boolean ascending, UserContext userContext, String ... path) {
        return sort(table, UserRoleAssignment.getBuilder(), recordIds, sortFieldName, ascending, userContext, path);
    }

    public static int getCount() {
        return table.getCount();
    }

    public UdbUserRoleAssignment() {
        super(table);
    }

    public UdbUserRoleAssignment(int id, boolean createEntity) {
        super(table, id, createEntity);
    }

    @Override
    public UserRoleAssignment build() {
        return new UdbUserRoleAssignment();
    }

    @Override
    public UserRoleAssignment build(int id) {
        return new UdbUserRoleAssignment(id, false);
    }

	@Override
	public Instant getMetaCreationDate() {
	    return getTimestampValue(metaCreationDate);
	}

	@Override
	public UserRoleAssignment setMetaCreationDate(Instant value) {
	    setTimestampValue(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaCreationDate);
	}

	@Override
	public UserRoleAssignment setMetaCreationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaCreationDate);
		return this;
	}

	@Override
	public long getMetaCreationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaCreationDate);
	}

	@Override
	public UserRoleAssignment setMetaCreationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreatedBy() {
        return getIntValue(metaCreatedBy);
	}

	@Override
	public UserRoleAssignment setMetaCreatedBy(int value) {
	    setIntValue(value, this.metaCreatedBy);
		return this;
	}

	@Override
	public Instant getMetaModificationDate() {
	    return getTimestampValue(metaModificationDate);
	}

	@Override
	public UserRoleAssignment setMetaModificationDate(Instant value) {
	    setTimestampValue(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModificationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaModificationDate);
	}

	@Override
	public UserRoleAssignment setMetaModificationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaModificationDate);
		return this;
	}

	@Override
	public long getMetaModificationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaModificationDate);
	}

	@Override
	public UserRoleAssignment setMetaModificationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModifiedBy() {
        return getIntValue(metaModifiedBy);
	}

	@Override
	public UserRoleAssignment setMetaModifiedBy(int value) {
	    setIntValue(value, this.metaModifiedBy);
		return this;
	}

	@Override
	public Instant getMetaDeletionDate() {
	    return getTimestampValue(metaDeletionDate);
	}

	@Override
	public UserRoleAssignment setMetaDeletionDate(Instant value) {
	    setTimestampValue(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletionDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaDeletionDate);
	}

	@Override
	public UserRoleAssignment setMetaDeletionDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public long getMetaDeletionDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaDeletionDate);
	}

	@Override
	public UserRoleAssignment setMetaDeletionDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletedBy() {
        return getIntValue(metaDeletedBy);
	}

	@Override
	public UserRoleAssignment setMetaDeletedBy(int value) {
	    setIntValue(value, this.metaDeletedBy);
		return this;
	}

	@Override
	public Instant getMetaRestoreDate() {
	    return getTimestampValue(metaRestoreDate);
	}

	@Override
	public UserRoleAssignment setMetaRestoreDate(Instant value) {
	    setTimestampValue(value, this.metaRestoreDate);
		return this;
	}

	@Override
	public int getMetaRestoreDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaRestoreDate);
	}

	@Override
	public UserRoleAssignment setMetaRestoreDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaRestoreDate);
		return this;
	}

	@Override
	public long getMetaRestoreDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaRestoreDate);
	}

	@Override
	public UserRoleAssignment setMetaRestoreDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaRestoreDate);
		return this;
	}

	@Override
	public int getMetaRestoredBy() {
        return getIntValue(metaRestoredBy);
	}

	@Override
	public UserRoleAssignment setMetaRestoredBy(int value) {
	    setIntValue(value, this.metaRestoredBy);
		return this;
	}

	@Override
	public User getUser() {
		if (isChanged(user)) {
			return (User) getReferenceChangeValue(user);
		} else {
			int id = user.getValue(getId());
			if (id > 0) {
				return User.getById(id);
			} else {
				return null;
			}
		}
	}

	@Override
	public UserRoleAssignment setUser(User value) {
		setSingleReferenceValue(user, value, table);
		return this;
	}

	@Override
	public Role getRole() {
		if (isChanged(role)) {
			return (Role) getReferenceChangeValue(role);
		} else {
			int id = role.getValue(getId());
			if (id > 0) {
				return Role.getById(id);
			} else {
				return null;
			}
		}
	}

	@Override
	public UserRoleAssignment setRole(Role value) {
		setSingleReferenceValue(role, value, table);
		return this;
	}

	@Override
	public OrganizationUnit getOrganizationUnit() {
		if (isChanged(organizationUnit)) {
			return (OrganizationUnit) getReferenceChangeValue(organizationUnit);
		} else {
			int id = organizationUnit.getValue(getId());
			if (id > 0) {
				return OrganizationUnit.getById(id);
			} else {
				return null;
			}
		}
	}

	@Override
	public UserRoleAssignment setOrganizationUnit(OrganizationUnit value) {
		setSingleReferenceValue(organizationUnit, value, table);
		return this;
	}

	@Override
	public int getDelegatedCustomPrivilegeObjectId() {
        return getIntValue(delegatedCustomPrivilegeObjectId);
	}

	@Override
	public UserRoleAssignment setDelegatedCustomPrivilegeObjectId(int value) {
	    setIntValue(value, this.delegatedCustomPrivilegeObjectId);
		return this;
	}

	@Override
	public boolean getMainResponsible() {
	    return getBooleanValue(mainResponsible);
	}

	@Override
	public UserRoleAssignment setMainResponsible(boolean value) {
	    setBooleanValue(value, this.mainResponsible);
		return this;
	}

	@Override
	public boolean isMainResponsible() {
	    return getBooleanValue(mainResponsible);
	}

	@Override
	public Instant getLastVerified() {
	    return getTimestampValue(lastVerified);
	}

	@Override
	public UserRoleAssignment setLastVerified(Instant value) {
	    setTimestampValue(value, this.lastVerified);
		return this;
	}

	@Override
	public int getLastVerifiedAsEpochSecond() {
	    return getTimestampAsEpochSecond(lastVerified);
	}

	@Override
	public UserRoleAssignment setLastVerifiedAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.lastVerified);
		return this;
	}

	@Override
	public long getLastVerifiedAsEpochMilli() {
	    return getTimestampAsEpochMilli(lastVerified);
	}

	@Override
	public UserRoleAssignment setLastVerifiedAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.lastVerified);
		return this;
	}

	@Override
	public User getLastVerifiedBy() {
		if (isChanged(lastVerifiedBy)) {
			return (User) getReferenceChangeValue(lastVerifiedBy);
		} else {
			int id = lastVerifiedBy.getValue(getId());
			if (id > 0) {
				return User.getById(id);
			} else {
				return null;
			}
		}
	}

	@Override
	public UserRoleAssignment setLastVerifiedBy(User value) {
		setSingleReferenceValue(lastVerifiedBy, value, table);
		return this;
	}



    @Override
    public UdbUserRoleAssignment save() {
        saveRecord(universalDB);
        return this;
    }

    @Override
    public void delete() {
        deleteRecord(universalDB);
    }

    @Override
    public void restoreDeleted() {
        restoreDeletedRecord(universalDB);
    }
}
